@@ -19,63 +19,64 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
  */
 
+#include <math.h>
 #include <gtk/gtk.h>
 #include "gradio.h"
 #include "pixmaps.h"
 
 /* Constant, unchanging parts of the display */
-GdkPixmap *leftmost_strip;
-GtkWidget *leftmost_strip_gtk;
-GdkPixmap *rightmost_strip;
-GtkWidget *rightmost_strip_gtk;
-GdkPixmap *top_left_strip;
-GtkWidget *top_left_strip_gtk;
-GdkPixmap *bottom_left_strip;
-GtkWidget *bottom_left_strip_gtk;
-GdkPixmap *top_right_strip;
-GtkWidget *top_right_strip_gtk;
-GdkPixmap *bottom_right_strip;
-GtkWidget *bottom_right_strip_gtk;
-GdkPixmap *vertical_strip;
-GtkWidget *vertical_strip_gtk[2];
+static GdkPixmap *leftmost_strip;
+static GtkWidget *leftmost_strip_gtk;
+static GdkPixmap *rightmost_strip;
+static GtkWidget *rightmost_strip_gtk;
+static GdkPixmap *top_left_strip;
+static GtkWidget *top_left_strip_gtk;
+static GdkPixmap *bottom_left_strip;
+static GtkWidget *bottom_left_strip_gtk;
+static GdkPixmap *top_right_strip;
+static GtkWidget *top_right_strip_gtk;
+static GdkPixmap *bottom_right_strip;
+static GtkWidget *bottom_right_strip_gtk;
+static GdkPixmap *vertical_strip;
+static GtkWidget *vertical_strip_gtk[2];
 
 /* The building blocks of the active display */
-GdkPixmap *small_v;
-GdkPixmap *small_t;
-GdkPixmap *small_m;
-GdkPixmap *small_k;
-GdkPixmap *small_d;
-GdkPixmap *small_f;
-GdkPixmap *small_s;
-GdkPixmap *small_digits[10];
-GdkPixmap *decimal_on;
-GdkPixmap *decimal_off;
-GdkPixmap *large_digits[10];
-GdkPixmap *small_blank;
-GdkPixmap *large_blank;
-GdkPixmap *power_on;
-GdkPixmap *power_off;
+static GdkPixmap *small_v;
+static GdkPixmap *small_t;
+static GdkPixmap *small_m;
+static GdkPixmap *small_k;
+static GdkPixmap *small_d;
+static GdkPixmap *small_f;
+static GdkPixmap *small_s;
+static GdkPixmap *small_digits[10];
+static GdkPixmap *decimal_on;
+static GdkPixmap *decimal_off;
+static GdkPixmap *large_digits[10];
+static GdkPixmap *small_blank;
+static GdkPixmap *large_blank;
+static GdkPixmap *power_on;
+static GdkPixmap *power_off;
 
-GdkBitmap *small_mask;
-GdkBitmap *large_mask;
-GdkBitmap *decimal_mask;
-GdkBitmap *vertical_strip_mask;
-GdkBitmap *power_mask;
+static GdkBitmap *small_mask;
+static GdkBitmap *large_mask;
+static GdkBitmap *decimal_mask;
+static GdkBitmap *vertical_strip_mask;
+static GdkBitmap *power_mask;
 
 /* The containers for the active display blocks */
-GtkWidget *volume_ind_gtk;
-GtkWidget *volume_digits_gtk[3];
-GtkWidget *tuned_ind_gtk;
-GtkWidget *muted_ind_gtk;
-GtkWidget *if_ind_gtk;
-GtkWidget *empty_ind_gtk;
-GtkWidget *freq_digits_gtk[6];
-GtkWidget *dp_gtk;
-GtkWidget *band_ind_left_gtk;
-GtkWidget *band_ind_right_gtk;
-GtkWidget *memset_ind_gtk;
-GtkWidget *memset_digit_gtk;
-GtkWidget *power;
+static GtkWidget *volume_ind_gtk;
+static GtkWidget *volume_digits_gtk[3];
+static GtkWidget *tuned_ind_gtk;
+static GtkWidget *muted_ind_gtk;
+static GtkWidget *if_ind_gtk;
+static GtkWidget *empty_ind_gtk;
+static GtkWidget *freq_digits_gtk[6];
+static GtkWidget *dp_gtk;
+static GtkWidget *band_ind_left_gtk;
+static GtkWidget *band_ind_right_gtk;
+static GtkWidget *memset_ind_gtk;
+static GtkWidget *memset_digit_gtk;
+static GtkWidget *power;
 
 extern radio_status gr_stat;
 
@@ -183,8 +184,9 @@ GtkWidget *gradio_get_memory_box (GtkWidget *w)
     GtkWidget *button_box[8];
     gint i;
 
-    static char **mem_buttons[] = { gr_mem_1_xpm, gr_mem_2_xpm, gr_mem_3_xpm, gr_mem_4_xpm, 
-				    gr_mem_5_xpm, gr_mem_6_xpm, gr_mem_7_xpm, gr_mem_8_xpm };
+    static char **mem_buttons[] = { gr_mem_1_xpm, gr_mem_2_xpm, gr_mem_3_xpm, 
+				    gr_mem_4_xpm, gr_mem_5_xpm, gr_mem_6_xpm, 
+				    gr_mem_7_xpm, gr_mem_8_xpm };
 
     main_box = gtk_vbox_new (FALSE, 0);
     top_box = gtk_hbox_new (FALSE, 0);
@@ -230,7 +232,6 @@ GtkWidget *gradio_get_control_box (GtkWidget *w)
     GtkWidget *power_button;
     GtkWidget *mute_button;
     GtkWidget *mute_box;
-    /*    GtkStyle *style = gtk_widget_get_style (w); */
 
     main_box = gtk_vbox_new (FALSE, 0);
 
@@ -283,42 +284,61 @@ GtkWidget *gradio_get_display (GtkWidget *w)
     gradio_pixmap_inits (w);
     gradio_set_display_from_status (); 
 
-    gtk_box_pack_start (GTK_BOX (left_top_box), volume_ind_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (left_top_box), volume_ind_gtk, TRUE, FALSE, 
+			0);
     for (i=0; i<3; i++)
-	gtk_box_pack_start (GTK_BOX (left_top_box), volume_digits_gtk[i], TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (left_top_box), volume_digits_gtk[i], TRUE,
+			    FALSE, 0);
     gtk_widget_show (left_top_box);
-    gtk_box_pack_start (GTK_BOX (left_bottom_box), tuned_ind_gtk, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (left_bottom_box), muted_ind_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (left_bottom_box), tuned_ind_gtk, TRUE, FALSE, 
+			0);
+    gtk_box_pack_start (GTK_BOX (left_bottom_box), muted_ind_gtk, TRUE, FALSE, 
+			0);
     gtk_box_pack_start (GTK_BOX (left_bottom_box), if_ind_gtk, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (left_bottom_box), empty_ind_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (left_bottom_box), empty_ind_gtk, TRUE, FALSE, 
+			0);
     gtk_widget_show (left_bottom_box);
-    gtk_box_pack_start (GTK_BOX (left_box), top_left_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (left_box), top_left_strip_gtk, TRUE, FALSE, 
+			0);
     gtk_box_pack_start (GTK_BOX (left_box), left_top_box, TRUE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (left_box), left_bottom_box, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (left_box), bottom_left_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (left_box), bottom_left_strip_gtk, TRUE, FALSE,
+			0);
     gtk_widget_show (left_box);
-    gtk_box_pack_start (GTK_BOX (right_top_box), band_ind_left_gtk, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (right_top_box), band_ind_right_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_top_box), band_ind_left_gtk, TRUE, 
+			FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_top_box), band_ind_right_gtk, TRUE, 
+			FALSE, 0);
     gtk_widget_show (right_top_box);
-    gtk_box_pack_start (GTK_BOX (right_bottom_box), memset_ind_gtk, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (right_bottom_box), memset_digit_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_bottom_box), memset_ind_gtk, TRUE, 
+			FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_bottom_box), memset_digit_gtk, TRUE, 
+			FALSE, 0);
     gtk_widget_show (right_bottom_box);
-    gtk_box_pack_start (GTK_BOX (right_box), top_right_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_box), top_right_strip_gtk, TRUE, FALSE, 
+			0);
     gtk_box_pack_start (GTK_BOX (right_box), right_top_box, TRUE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (right_box), right_bottom_box, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (right_box), bottom_right_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (right_box), bottom_right_strip_gtk, TRUE, 
+			FALSE, 0);
     gtk_widget_show (right_box);
-    gtk_box_pack_start (GTK_BOX (main_box), leftmost_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (main_box), leftmost_strip_gtk, TRUE, FALSE, 
+			0);
     gtk_box_pack_start (GTK_BOX (main_box), left_box, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (main_box), vertical_strip_gtk[0], TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (main_box), vertical_strip_gtk[0], TRUE, FALSE,
+			0);
     for (i=0; i<4; i++)
-	gtk_box_pack_start (GTK_BOX (main_box), freq_digits_gtk[i], TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (main_box), freq_digits_gtk[i], TRUE, 
+			    FALSE, 0);
     gtk_box_pack_start (GTK_BOX (main_box), dp_gtk, TRUE, FALSE, 0);
     for (i=4; i<6; i++)
-	gtk_box_pack_start (GTK_BOX (main_box), freq_digits_gtk[i], TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (main_box), vertical_strip_gtk[1], TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (main_box), freq_digits_gtk[i], TRUE, 
+			    FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (main_box), vertical_strip_gtk[1], TRUE, FALSE,
+			0);
     gtk_box_pack_start (GTK_BOX (main_box), right_box, TRUE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (main_box), rightmost_strip_gtk, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (main_box), rightmost_strip_gtk, TRUE, FALSE, 
+			0);
     gtk_widget_show (main_box);
     main_event_box = gtk_event_box_new ();
     gtk_container_add (GTK_CONTAINER (main_event_box), main_box);
@@ -382,10 +402,7 @@ GtkWidget *xpm_label_box_d (GtkWidget *parent, gchar **xpm_d, gchar *label_text)
     gtk_box_pack_start (GTK_BOX (box1),
 			pixmapwid, TRUE, FALSE, 0);
     
-    /*    gtk_box_pack_start (GTK_BOX (box1), label, FALSE, FALSE, 3); */
-    
     gtk_widget_show(pixmapwid);
-    /*    gtk_widget_show(label); */
     
     return (box1);
 }
@@ -395,97 +412,170 @@ void gradio_pixmap_inits (GtkWidget *w)
     GdkBitmap *mask;
     GtkStyle *style = gtk_widget_get_style (w);
     int i;
-    vertical_strip = gdk_pixmap_create_from_xpm_d (w->window, &vertical_strip_mask, 
-						   &style->bg[GTK_STATE_NORMAL],
+    vertical_strip = gdk_pixmap_create_from_xpm_d (w->window, 
+						   &vertical_strip_mask, 
+						   &style
+						   ->bg[GTK_STATE_NORMAL],
 						   (gchar**) vertical_strip_d);
-    vertical_strip_gtk[0] = gtk_pixmap_new (vertical_strip, vertical_strip_mask);
-    vertical_strip_gtk[1] = gtk_pixmap_new (vertical_strip, vertical_strip_mask);
-    small_v = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    vertical_strip_gtk[0] = gtk_pixmap_new (vertical_strip, 
+					    vertical_strip_mask);
+    vertical_strip_gtk[1] = gtk_pixmap_new (vertical_strip, 
+					    vertical_strip_mask);
+    small_v = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_v_d);
-    small_t = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_t = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_t_d);
-    small_m = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_m = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_m_d);
-    small_k = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    small_k = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_k_d);
-    small_d = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_d = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_d_d);
-    small_f = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_f = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_f_d);
-    small_s = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_s = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+					    &style->bg[GTK_STATE_NORMAL],
 					    (gchar**) small_s_d);
-    small_blank = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_blank = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						&style->bg[GTK_STATE_NORMAL],
 						(gchar**) small_blank_d);
-    small_digits[0] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[0] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_0_d);
-    small_digits[1] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[1] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_1_d);
-    small_digits[2] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[2] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_2_d);
-    small_digits[3] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[3] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_3_d);
-    small_digits[4] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[4] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_4_d);
-    small_digits[5] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[5] = gdk_pixmap_create_from_xpm_d (w->window, &small_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_5_d);
-    small_digits[6] = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[6] = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_6_d);
-    small_digits[7] = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[7] = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_7_d);
-    small_digits[8] = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[8] = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_8_d);
-    small_digits[9] = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    small_digits[9] = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) small_9_d);
-    large_blank = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    large_blank = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						&style->bg[GTK_STATE_NORMAL],
 						(gchar**) large_blank_d);
-    large_digits[0] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[0] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_0_d);
-    large_digits[1] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[1] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_1_d);
-    large_digits[2] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[2] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_2_d);
-    large_digits[3] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[3] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_3_d);
-    large_digits[4] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[4] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_4_d);
-    large_digits[5] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[5] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_5_d);
-    large_digits[6] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[6] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_6_d);
-    large_digits[7] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[7] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_7_d);
-    large_digits[8] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[8] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_8_d);
-    large_digits[9] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, &style->bg[GTK_STATE_NORMAL],
+    large_digits[9] = gdk_pixmap_create_from_xpm_d (w->window, &large_mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
 						    (gchar**) large_9_d);
-    leftmost_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    leftmost_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						   &style
+						   ->bg[GTK_STATE_NORMAL],
 						   (gchar**) leftmost_strip_d);
     leftmost_strip_gtk = gtk_pixmap_new (leftmost_strip, mask);
-    rightmost_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
-						   (gchar**) rightmost_strip_d);
+    rightmost_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style
+						    ->bg[GTK_STATE_NORMAL],
+						    (gchar**) 
+						    rightmost_strip_d);
     rightmost_strip_gtk = gtk_pixmap_new (rightmost_strip, mask);
-    top_left_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
+    top_left_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						   &style
+						   ->bg[GTK_STATE_NORMAL],
 						   (gchar**) top_left_strip_d);
     top_left_strip_gtk = gtk_pixmap_new (top_left_strip, mask);
-    bottom_left_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
-						   (gchar**) bottom_left_strip_d);
+    bottom_left_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						      &style
+						      ->bg[GTK_STATE_NORMAL],
+						      (gchar**) 
+						      bottom_left_strip_d);
     bottom_left_strip_gtk = gtk_pixmap_new (bottom_left_strip, mask);
-    top_right_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
-						   (gchar**) top_right_strip_d);
+    top_right_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						    &style->
+						    bg[GTK_STATE_NORMAL],
+						    (gchar**) 
+						    top_right_strip_d);
     top_right_strip_gtk = gtk_pixmap_new (top_right_strip, mask);
-    bottom_right_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, &style->bg[GTK_STATE_NORMAL],
-						   (gchar**) bottom_right_strip_d);
+    bottom_right_strip = gdk_pixmap_create_from_xpm_d (w->window, &mask, 
+						       &style
+						       ->bg[GTK_STATE_NORMAL],
+						       (gchar**) 
+						       bottom_right_strip_d);
     bottom_right_strip_gtk = gtk_pixmap_new (bottom_right_strip, mask);
-    decimal_on = gdk_pixmap_create_from_xpm_d (w->window, &decimal_mask, &style->bg[GTK_STATE_NORMAL],
+    decimal_on = gdk_pixmap_create_from_xpm_d (w->window, &decimal_mask, 
+					       &style->bg[GTK_STATE_NORMAL],
 					       (gchar**) decimal_on_d);
-    decimal_off = gdk_pixmap_create_from_xpm_d (w->window, &decimal_mask, &style->bg[GTK_STATE_NORMAL],
+    decimal_off = gdk_pixmap_create_from_xpm_d (w->window, &decimal_mask, 
+						&style->bg[GTK_STATE_NORMAL],
 						(gchar**) decimal_off_d);
-    power_off = gdk_pixmap_create_from_xpm_d (w->window, &power_mask, &style->bg[GTK_STATE_NORMAL],
+    power_off = gdk_pixmap_create_from_xpm_d (w->window, &power_mask, 
+					      &style->bg[GTK_STATE_NORMAL],
 					      (gchar**) gr_power_off_xpm);
-    power_on = gdk_pixmap_create_from_xpm_d (w->window, &power_mask, &style->bg[GTK_STATE_NORMAL],
-					      (gchar**) gr_power_on_xpm);
+    power_on = gdk_pixmap_create_from_xpm_d (w->window, &power_mask, 
+					     &style->bg[GTK_STATE_NORMAL],
+					     (gchar**) gr_power_on_xpm);
     power = gtk_pixmap_new (power_on, power_mask);
-
+    
     volume_ind_gtk = gtk_pixmap_new (small_v, small_mask);
     for (i=0; i<3; i++)
 	volume_digits_gtk[i] = gtk_pixmap_new (small_blank, small_mask);
@@ -530,26 +620,31 @@ void gradio_pixmap_inits (GtkWidget *w)
 
 void gradio_set_display_from_status (void)
 {
-    /*    GdkBitmap *mask; */
     int i;
 
     if (gr_stat.power == FALSE) { /* Blank the whole display */
 	gtk_pixmap_set (GTK_PIXMAP (volume_ind_gtk), small_blank, small_mask);
 	for (i=0; i<3; i++) {
-	    gtk_pixmap_set (GTK_PIXMAP (volume_digits_gtk[i]), small_blank, small_mask);
-	    gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[i]), large_blank, large_mask);
+	    gtk_pixmap_set (GTK_PIXMAP (volume_digits_gtk[i]), small_blank, 
+			    small_mask);
+	    gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[i]), large_blank, 
+			    large_mask);
 	}
 	for (i=3; i<6; i++)
-	    gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[i]), large_blank, large_mask);
+	    gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[i]), large_blank, 
+			    large_mask);
 	gtk_pixmap_set (GTK_PIXMAP (power), power_off, power_mask);
 	gtk_pixmap_set (GTK_PIXMAP (tuned_ind_gtk), small_blank, small_mask);
 	gtk_pixmap_set (GTK_PIXMAP (muted_ind_gtk), small_blank, small_mask);
 	gtk_pixmap_set (GTK_PIXMAP (if_ind_gtk), small_blank, small_mask);
 	gtk_pixmap_set (GTK_PIXMAP (dp_gtk), decimal_off, decimal_mask);
-	gtk_pixmap_set (GTK_PIXMAP (band_ind_left_gtk), small_blank, small_mask);
-	gtk_pixmap_set (GTK_PIXMAP (band_ind_right_gtk), small_blank, small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (band_ind_left_gtk), small_blank, 
+			small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (band_ind_right_gtk), small_blank, 
+			small_mask);
 	gtk_pixmap_set (GTK_PIXMAP (memset_ind_gtk), small_blank, small_mask);
-	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), small_blank, small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), small_blank, 
+			small_mask);
 	return;
     }
     
@@ -558,9 +653,9 @@ void gradio_set_display_from_status (void)
 	gtk_pixmap_set (GTK_PIXMAP (muted_ind_gtk), small_m, small_mask);
     else
 	gtk_pixmap_set (GTK_PIXMAP (muted_ind_gtk), small_blank, small_mask);
-    if (gr_stat.interface == GR_IF_KERNEL)
+    if (TRUE) /* We ALWAYS use the kernel interface now */
 	gtk_pixmap_set (GTK_PIXMAP (if_ind_gtk), small_k, small_mask);
-    else
+    else /* Unreached */
 	gtk_pixmap_set (GTK_PIXMAP (if_ind_gtk), small_d, small_mask);
     if (gr_stat.tuned)
 	gtk_pixmap_set (GTK_PIXMAP (tuned_ind_gtk), small_t, small_mask);
@@ -573,87 +668,43 @@ void gradio_set_display_from_status (void)
     for (i=0; i<3; i++)
 	gtk_pixmap_set (GTK_PIXMAP (volume_digits_gtk[i]), 
 			/* Extract digit */
-			small_digits[((int)(gr_stat.vol*(100./(float)GR_VOL_MAX)/
-					    (float)(pow(10,2-i))+((i==2)?.5:0)))%10],
-			small_mask);
-    if (TRUE)
+			small_digits[((int)
+				      (gr_stat.vol * (100. / (float)GR_VOL_MAX)
+						      / (float)(pow(10,2-i))
+						      +((i==2)?.5:0)))%10],
+				    small_mask);
+    if (TRUE) /* Huh? */
 	gtk_pixmap_set (GTK_PIXMAP (band_ind_left_gtk), small_f, small_mask);
     else
-	gtk_pixmap_set (GTK_PIXMAP (band_ind_left_gtk), small_blank, small_mask);
-    if (TRUE)
+	gtk_pixmap_set (GTK_PIXMAP (band_ind_left_gtk), small_blank, 
+			small_mask);
+    if (TRUE) /* ... */
 	gtk_pixmap_set (GTK_PIXMAP (band_ind_right_gtk), small_m, small_mask);
     else
-	gtk_pixmap_set (GTK_PIXMAP (band_ind_right_gtk), small_blank, small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (band_ind_right_gtk), small_blank, 
+			small_mask);
     if (TRUE)
 	gtk_pixmap_set (GTK_PIXMAP (memset_ind_gtk), small_blank, small_mask);
     else
 	gtk_pixmap_set (GTK_PIXMAP (memset_ind_gtk), small_blank, small_mask);
     if (gr_stat.memset != -1)
-	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), small_digits[gr_stat.memset], small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), 
+			small_digits[gr_stat.memset], small_mask);
     else
-	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), small_blank, small_mask);
+	gtk_pixmap_set (GTK_PIXMAP (memset_digit_gtk), small_blank, 
+			small_mask);
     gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[1]), 
 		    /* Extract digit */
 		    (gr_stat.freq<100000) ? large_blank 
-		    : large_digits[((gr_stat.freq)/(int)(pow (10, (5-0))))%10], 
+		    : large_digits[((gr_stat.freq)/(int)(pow (10, (5-0))))%10],
 		    large_mask);
     for (i=2; i<6; i++)
 	gtk_pixmap_set (GTK_PIXMAP (freq_digits_gtk[i]), 
 			/* Extract digit */
-			large_digits[((gr_stat.freq)/(int)(pow (10,(6-i))))%10], 
-			large_mask);
-    if (TRUE)
+			large_digits[((gr_stat.freq)/(int)(pow(10,(6-i))))%10],
+ 			large_mask);
+    if (TRUE) /* ... */
 	gtk_pixmap_set (GTK_PIXMAP (dp_gtk), decimal_on, decimal_mask);
     else
 	gtk_pixmap_set (GTK_PIXMAP (dp_gtk), decimal_off, decimal_mask);
 }
-
-void gradio_get_port (int *addr)
-{
-    GtkWidget *dialog;
-    GtkWidget *button2;
-    GtkWidget *button3;
-    GtkWidget *label1;
-    GtkWidget *label2;
-    GtkWidget *ok_button;
-    GtkWidget *hbox1, *hbox2;
-    GSList *group;
-    
-    dialog = gtk_dialog_new ();
-    gtk_widget_set_name (dialog, "addr_dlg");
-    label1 = gtk_label_new ("Your card could not be autodetected.");
-    label2 = gtk_label_new ("Select an i/o port to use:");
-    button2 = gtk_radio_button_new_with_label (NULL, "0x20c");
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button2));
-    button3 = gtk_radio_button_new_with_label (group, "0x30c");
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button3));
-    hbox1 = gtk_hbox_new (FALSE, 4);
-    hbox2 = gtk_hbox_new (FALSE, 4);
-    gtk_box_pack_start (GTK_BOX (hbox1), button2, TRUE, FALSE, 4);
-    gtk_box_pack_start (GTK_BOX (hbox2), button3, TRUE, FALSE, 4);
-    gtk_widget_show (hbox1);
-    gtk_widget_show (hbox2);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label1, TRUE, TRUE, 2);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label2, TRUE, TRUE, 2);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox1, TRUE, TRUE, 4);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox2, TRUE, TRUE, 4);
-    ok_button = gtk_button_new_with_label ("OK");
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), ok_button, TRUE, TRUE, 8);
-    
-    /* This warrants some explanation. The first call causes gradio_port_ok_cb to store the
-     * address selected. The second call stores this value in "addr" so it can be returned.
-     * The third call causes the dialog box to be destroyed.
-     */
-    gtk_signal_connect (GTK_OBJECT (ok_button), "clicked", GTK_SIGNAL_FUNC (gradio_port_ok_cb),
-			(gpointer) button2);
-    gtk_signal_connect (GTK_OBJECT (ok_button), "clicked", GTK_SIGNAL_FUNC (gradio_port_ok_cb),
-			(gpointer) addr);
-    gtk_signal_connect (GTK_OBJECT (ok_button), "clicked", GTK_SIGNAL_FUNC (gradio_close_dialog_cb),
-			(gpointer) dialog);
-    gtk_widget_show (button2);
-    gtk_widget_show (button3);
-    gtk_widget_show (label1);
-    gtk_widget_show (label2);
-    gtk_widget_show (ok_button);
-    gtk_widget_show (dialog);
-}
